/*
 * The MIT License
 *
 * Copyright 2017 Germán Bordel <german.bordel at ehu.es>.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package edu.upvehu.gb.ejemplos.paintOnJPanel;

import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics;
import javax.swing.JSlider;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

/**
 * JPanel que en caso de recibir un JSlider pinta un rectangulo de tamalo variable con su valor.
 * 
 * @author Germán Bordel <german.bordel at ehu.es>
 */
public class DynamicRectangleJPanel extends javax.swing.JPanel implements ChangeListener {
    int porcentajeDeDesplazamiento;
    
    @Override
    public void paint(Graphics g) {
        super.paint(g); 
        
        g.drawRect( getWidth()*(100-porcentajeDeDesplazamiento)/200,
                getHeight()*(100-porcentajeDeDesplazamiento)/200,
                getWidth()*porcentajeDeDesplazamiento/100-1,
                getHeight()*porcentajeDeDesplazamiento/100-1
        );
        
        g.setColor(Color.red);
        g.setFont(new Font("Serif",Font.BOLD+Font.ITALIC,14));
        g.drawString("Tamaño del panel: "+getWidth()+"x"+getHeight(), 0, 14);
        g.drawString("Valor del JSlider: "+porcentajeDeDesplazamiento, 0, 28);
        
    }     

    @Override
    public void stateChanged(ChangeEvent e) {
        porcentajeDeDesplazamiento=((JSlider)e.getSource()).getValue();
        repaint();
    }

    void recibeSlider(JSlider s){
        porcentajeDeDesplazamiento=s.getValue();
        s.addChangeListener(this);
    }
}
